############
Installation
############

If you want to use the GUI version, grab the latest executable from the
`GitHub release page <https://github.com/bbtufty/romsearch/releases/latest>`_.

ROMSearch is also pip-installable: ::

  pip install romsearch

Or can be installed via GitHub for the latest version: ::

  git clone https://github.com/bbtufty/romsearch.git
  pip install -e .
